import { ScanOptions } from './interfaces/ITScanOptions';
/**
 * Escanea el cuerpo de una solicitud HTTP y busca posibles problemas de seguridad.
 *
 * @param body - El cuerpo de la solicitud HTTP.
 * @param options - Opciones de escaneo.
 * @returns Un array de cadenas que representan los problemas encontrados en el escaneo.
 *
 * @remarks
 * Esta función escanea el cuerpo de una solicitud HTTP en busca de posibles problemas de seguridad.
 * Puede escanear las claves y/o los valores del cuerpo, dependiendo de las opciones proporcionadas.
 * Los problemas encontrados se agregan a un array y se devuelven al final del escaneo.
 *
 * @example
 * ```typescript
 * const body = { username: 'admin', password: '123456' };
 * const options = { keys: true, values: true };
 * const issues = scanBody(body, options);
 * console.log(issues); ['admin', '123456']
 * ```
 *
 * @author Andres Gutierrez Velez
 * @since 21/06/2024
 * @contact sr.willardkraft@gmail.com
 */
export declare function scanBody(body: Record<string, any>, options: ScanOptions): string[];
